pub enum Action {
Cancellation,
Request(RequestedKeyInfo),
}Expand description
Enum describing different actions a room key request event can be carrying.
Variants
Cancellation
An action describing a cancellation of a previous room key request.
Request(RequestedKeyInfo)
An action describing a room key request.