pub enum RequestedKeyInfo {
MegolmV1AesSha2(MegolmV1AesSha2Content),
Unknown(UnknownRoomKeyRequest),
}Expand description
Info about the room key that is being requested.
Variants
MegolmV1AesSha2(MegolmV1AesSha2Content)
The m.megolm.v1.aes-sha2 variant of the m.room_key_request content.
Unknown(UnknownRoomKeyRequest)
An unknown and unsupported variant of the m.room_key_request
content.
Implementations
Sourceimpl RequestedKeyInfo
impl RequestedKeyInfo
Sourcepub fn algorithm(&self) -> EventEncryptionAlgorithm
pub fn algorithm(&self) -> EventEncryptionAlgorithm
Get the algorithm of the room key request content.